# Monitoring WebSocket Server

A real-time system monitoring application that collects system metrics (CPU, memory, disk, GPU) and broadcasts them via WebSocket to connected clients.

## Features

- Real-time system monitoring (CPU, memory, disk, GPU)
- WebSocket server for broadcasting metrics
- Configurable alert thresholds
- Multiple data export formats
- Standalone WebSocket server mode
- GPU monitoring with automatic detection

## Installation

```bash
pip install monitoring-websocket-server
```

## Quick Start

### Run as Standalone WebSocket Server

```bash
python -m run_server
```

The server will start on `ws://localhost:8765` by default.

### Use in Your Application

```python
from monitoring_websocket_server import StandaloneWebSocketServer

# Create and start the server
server = StandaloneWebSocketServer(host='0.0.0.0', port=8765)
await server.start()
```

## Configuration

The system can be configured via JSON/YAML files or programmatically:

```python
from monitoring_websocket_server.config import ConfigurationManager

config = ConfigurationManager()
config.set_alert_thresholds({
    'memory': {'warning': 80, 'critical': 90},
    'cpu': {'warning': 80, 'critical': 95},
    'disk': {'warning': 85, 'critical': 95}
})
```

## Architecture

- **Core**: Data models and enums
- **Monitors**: System metric collectors (CPU, memory, disk, GPU)
- **Services**: Core monitoring and WebSocket services
- **Exporters**: Data export mechanisms
- **Alerts**: Configurable alert system with thresholds

## Development

```bash
# Install dependencies
pip install -r requirements.txt

# Run tests
python test_client.py
python test_gpu.py
```

## License

GPL-3.0-or-later

## Author

NMicInvest - accueil@nmicinvest.com